@@ -59,17 +59,17 @@ class quantum_lab():
         print("{:<15} {:<5}".format("ID", "Status"))
         print("{:<15} {:<5}".format(data["jobId"], data["status"]))
 
-        jobID = data["jobId"]
+        jobID = data["id"]
 
         time_num = 0
         while True:
-            response = requests.post(f"http://sdt-api.qcc.svc.cluster.local/qcc/notebook/job/{jobID}", headers=headers, data=body) 
+            time.sleep(1)
+            response = requests.get(f"http://sdt-api.qcc.svc.cluster.local/qcc/notebook/job/{jobID}", headers=headers) 
             data = response.json()
             p_status = data["jobStatus"]
             print(f"Time: {time_num} / Status: {p_status}")
             if p_status == "Success" or p_status == "Failed":
                 break
-            time.sleep(1)
             time_num += 1
 
             if time_num > 60:
